pub enum TimeUpdateStrategy {
Automatic,
ManualInstant(Instant),
ManualDuration(Duration),
FixedTimesteps(u32),
}Expand description
Configuration resource used to determine how the time system should run.
For most cases, TimeUpdateStrategy::Automatic is fine. When writing tests, dealing with
networking or similar, you may prefer to set the next Time value manually.
Variants
Automatic
Time will be automatically updated each frame using an Instant sent from the render world.
If nothing is sent, the system clock will be used instead.
See TimeSender for more details.
ManualInstant(Instant)
Time will be updated to the specified Instant value each frame.
In order for time to progress, this value must be manually updated each frame.
Note that the Time resource will not be updated until TimeSystems runs.
ManualDuration(Duration)
FixedTimesteps(u32)
Time will be incremented by the fixed timestep each frame, multiplied by the specified factor n.
This means that a call to App::update will always run the fixed loop exactly n times.